@@ -1,7 +1,7 @@
 package Complete::Man;
 
-our $DATE = '2015-09-09'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2016-10-14'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -28,10 +28,6 @@ _
             req => 1,
             pos => 0,
         },
-        ci => {
-            summary => 'Whether to do case-insensitive search',
-            schema  => 'bool*',
-        },
         section => {
             summary => 'Only search from this section',
             schema  => 'str*',
@@ -75,7 +71,6 @@ sub complete_manpage {
     Complete::Util::complete_array_elem(
         word => $args{word},
         array => \@res,
-        ci => $args{ci},
     );
 }
 
@@ -94,7 +89,7 @@ Complete::Man - Complete from list of available manpages
 
 =head1 VERSION
 
-This document describes version 0.04 of Complete::Man (from Perl distribution Complete-Man), released on 2015-09-09.
+This document describes version 0.05 of Complete::Man (from Perl distribution Complete-Man), released on 2016-10-14.
 
 =head1 SYNOPSIS
 
@@ -117,14 +112,12 @@ Complete from list of available manpages.
 For each directory in C<MANPATH> environment variable, search man section
 directories and man files.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
-Whether to do case-insensitive search.
-
 =item * B<section> => I<str>
 
 Only search from this section.
@@ -157,7 +150,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
